@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.13   2015/06/06
+ * Version: 0.1.14   2015/07/21
  */
 
 #include <linux/version.h>
@@ -41,6 +41,10 @@ static int __init cs_setup(char *str)
 
 __setup("caitsith=", cs_setup);
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 0, 0)
+#include "lsm2caitsith.c"
+#endif
+
 #ifndef CONFIG_CAITSITH_OMIT_USERSPACE_LOADER
 
 /* Path to the policy loader. (default = CONFIG_CAITSITH_POLICY_LOADER) */
@@ -231,6 +235,9 @@ const struct caitsith_exports caitsith_exports = {
 #ifndef CONFIG_CAITSITH_OMIT_USERSPACE_LOADER
 	.load_policy = cs_load_policy,
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0) && defined(CONFIG_SECURITY)
+	.add_hooks = cs_add_hooks,
+#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 2, 0)
 	.d_absolute_path = d_absolute_path,
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36)
