@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.13   2015/06/06
+ * Version: 0.1.14   2015/07/21
  */
 
 #ifndef _LINUX_CAITSITH_H
@@ -35,6 +35,10 @@ int search_binary_handler(struct linux_binprm *bprm);
 int search_binary_handler(struct linux_binprm *bprm, struct pt_regs *regs);
 #endif
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 0, 0)
+#include <linux/lsm2caitsith.h>
+#endif
+
 #ifdef CONFIG_CAITSITH
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36) && LINUX_VERSION_CODE < KERNEL_VERSION(3, 2, 0)
@@ -49,6 +53,9 @@ int search_binary_handler(struct linux_binprm *bprm, struct pt_regs *regs);
 /* For exporting variables and functions. */
 struct caitsith_exports {
 	void (*load_policy) (const char *filename);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0) && defined(CONFIG_SECURITY)
+	void (*add_hooks) (void);
+#endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 2, 0)
 	char * (*d_absolute_path) (const struct path *, char *, int);
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36)
